<?php

namespace HCM\FPA\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;

class TipoAssociacaoContabilController extends Crud {
 
    protected $dataSourceName = 'fpa_tpeventoctbl_get';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_DTMESCOMPETENC', 'P_NRORG_PADRAO');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        parent::__construct($dataSourceManager);
    }
 
    public function getTpAssociacaoContabil(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria(); 
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    } 
    
    public function setTipoAssociacaoContabil(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if ($row['__is_new'] ) {
                    $row['NRTPEVENTOCTBL'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'FPA_TPEVENTOCTBL', 1, 12, true); 
                }
                $dstpeventoctbl = $row['DSTPEVENTOCTBL'];
                if(strlen($dstpeventoctbl) > 50){
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message('Operação bloqueada! Não é possível inserir mais de 50 caracteres para o campo de Descrição.', DTO\Response\Message::TYPE_ERROR));
                    return;
                }
            }
            parent::save($request, $response);
                
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteTipodeAssociacao(DTO\Request\DataSet $request, DTO\Response $response){
        try{
            parent::delete($request, $response);
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }    
    }


    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }

} 