<?php

namespace HCM\FPA\ObrigacaoLegal\CNAB\Brasil\registro;

use HCM\Util\Messages;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;
use HCM\Util\FPA;
use HCM\Util\TkDI;
use HCM\Util\MsgCalculo;
use HCM\FPA\Registro\RegistroCNAB;
use HCM\FPA\ObrigacaoLegal\CNAB\Brasil\CNABBrasil;

class Registro3ACNABBrasil extends RegistroCNAB{

    const SEGMENTO_A = 'A';
    const CODIGO_CAMARA_COMPENSACAO_CC = '000';
    const FINALIDADE_CREDITOCONTA = '01';
    const TIPO_MOEDA = 'BRL';

    private $_pessoa;
    private $_vinculo;
    private $_cnpjEmpresa;

    public function geraRegistro3A(){
        $this->_geraRegistro();
    }

    private function _geraRegistro(){
        // Bloco 1 ao 3 eh gerado no pai.
        parent::geraRegistro(self::REGISTRO_3, CNABBrasil::CODIGO_BANCO_DO_BRASIL, self::LOTE_SERVICO);

        // Bloco 4 | 009-013 | Numero Sequencial do Registro no Lote.
        // identifica a sequencia de registros encaminhados no lote. Deve ser inicializado sempre em ‘00001’, em cada novo lote.
        // Definido apos a geracao de todos os registros do arquivo (a sequencia eh modificada no PercorreCaged).
        $this->atribuiDado(parent::CARACTER_ZERO, 5, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 5 | 014 | Codigo Segmento do Registro Detalhe.
        $this->atribuiDado(self::SEGMENTO_A, 1);

        // Bloco 6 | 015 | Tipo de Movimento.
        // 0 = Indica INCLUSAO
        // 3 = Indica ESTORNO (somente para retorno)
        // 5 = Indica ALTERACAO
        // 8 = Indica INCLUSAO COMPROR* (Necessario possuir Compror Eletronico contratado e operacao cadastrada.)
        // 9 = Indica EXCLUSAO
        $this->atribuiDado(parent::CARACTER_ZERO, 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 7 | 016-017 | Codigo da Instrucao para Movimento.
        // 00 = Inclusao de Registro Detalhe Liberado
        // 09 = Inclusao do Registro Detalhe Bloqueado
        // 10 = Alteracao do Pagamento Liberado para Bloqueado (Bloqueio)
        // 11 = Alteracao do Pagamento Bloqueado para Liberado (Desbloqueio)
        // 14 = Autorizacao do Pagamento
        // 33 = Estorno por Devolucao da Camara Centralizadora (somente Tipo de Movimento = 3)
        $this->atribuiDado(parent::CARACTER_ZERO, 2, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 8 | 018-020 | Codigo Camara Compensacao.
        // Passando 000 (CC) como default.
        // 018 = TED CIP
        // 810 = TED STR
        // 700 = DOC
        // 000 = CC
        $this->atribuiDado(self::CODIGO_CAMARA_COMPENSACAO_CC, 3, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 9 | 021-023 | Codigo do Banco Favorecido (Obrigatorio).
        $this->atribuiDado($this->_pessoa->banco, 3, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 10 | 024-028 | Codigo da Agencia Favorecido.
        $this->atribuiDado($this->_pessoa->agencia, 6, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 11 | 029 | Digito Verificador da Agencia.
        //$this->atribuiDado(parent::retornaDigitoContaCorrente($this->_pessoa->contaCorrente), 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 12 | 030-041 | Conta Corrente do Favorecido.
        // Conta Corrente deve ser informada sem DV, pois este deve ser preenchido na posicao 42.
        $this->atribuiDado(parent::retornaContaCorrenteSemDigito($this->_pessoa->contaCorrente), 12, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 13 | 042 | Digito Verificador da Conta.
        $this->atribuiDado(parent::retornaDigitoContaCorrente($this->_pessoa->contaCorrente), 1, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 14 | 043 | Digito Verificador da Agencia / Conta.
        $this->atribuiDado(parent::CARACTER_BRANCO, 1, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 15 | 044-073 | Nome do Favorecido (Obrigatorio).
        $this->atribuiDado($this->_pessoa->historico->getNmpessoa(), 30, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 16 | 074-093 | Nro. do Documento Cliente (seu numero).
        // Numero atribuido pela Empresa (Pagador) para identificar o documento de Pagamento (Nota
        // Fiscal, Nota Promissoria, etc.).
        // Caso parametro “Seu Numero Obrigatorio” tenha sido contratado no convenio, a informacao de
        // “Seu Numero” e “CPF/CNPJ Fornecedor” se torna campo “chave” para caracterizar duplicidade.
        // Em caso de TED eh informado.
//        $this->atribuiDado($this->_cnpjEmpresa, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
        $this->atribuiDado($this->_vinculo->getCdmatricula(), 10, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);
        //complemento
        $this->atribuiDado(parent::CARACTER_BRANCO, 10, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 17 | 094-101 | Data do Pagamento (DDMMAAAA).
        $this->atribuiDado($this->_vinculo->dataPagamento, 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 18 | 102-104 | Tipo da Moeda. Utilizar “BRL” (Real).
        $this->atribuiDado(self::TIPO_MOEDA, 3, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 19 | 105-119 | Quantidade de Moeda. Preencher com zero.
        $this->atribuiDado(parent::CARACTER_ZERO, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 20 | 120-134 | Valor do Pagamento (Obrigatorio). Salario liquido.
        $this->atribuiDado($this->_vinculo->valorPagamento, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 21 | 135-154 | Nro. do Documento Banco (Nosso Numero).
        // Numero atribuido pelo Banco para identificar o lancamento, que sera utilizado nas manutencoes do mesmo.
        $this->atribuiDado(parent::CARACTER_BRANCO, 20, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 22 | 155-162 | Data Real do Pagamento (DDMMAAAA).
//        $this->atribuiDado($this->_vinculo->dataPagamento, 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);
        $this->atribuiDado(0, 8, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 23 | 163-177 | Valor Real do Pagamento (Opcional).
//        $this->atribuiDado($this->_vinculo->valorPagamento, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);
        $this->atribuiDado(0, 15, parent::CARACTER_ZERO, parent::PREENCHE_ESQUERDA);

        // Bloco 24 | 178-217 | Outras Informacoes (Opcional).
        $this->atribuiDado(parent::CARACTER_BRANCO, 40, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 25 | 218-219 | Finalidade do DOC, TED CIP e TED STR. Passando fixo 01 (credito em conta).
        //$this->atribuiDado(self::FINALIDADE_CREDITOCONTA, 2, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
        $this->atribuiDado(parent::CARACTER_BRANCO, 2, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 26 | 220-229 | Filler.
        $this->atribuiDado(parent::CARACTER_BRANCO, 10, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 27 | 230 | Emissao Aviso ao Favorecido. Passando 0 fixo.
        // Codigo para identificar a necessidade de emissao de aviso de pagamento ao Favorecido.
        // 0 = Nao Emite Aviso
        // 2 = Emite Aviso Somente para o Remetente
        // 5 = Emite Aviso Somente para o Favorecido
        // 6 = Emite Aviso para o Remetente e Favorecido
        $this->atribuiDado(parent::CARACTER_ZERO, 1, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);

        // Bloco 28 | 231-240 | Ocorrencias para o Retorno.
        // Codigo adotado para identificar as ocorrencias detectadas no processamento.
        // Pode-se informar ate 5 ocorrencias simultaneamente, cada uma delas codificada com dois
        // digitos, conforme relacao das paginas 32 e 33.
        $this->atribuiDado(parent::CARACTER_BRANCO, 10, parent::CARACTER_BRANCO, parent::PREENCHE_DIREITA);
    }

    public function setPessoa($pessoa)
    {
        $this->_pessoa = $pessoa;
    }

    public function setVinculo($vinculo)
    {
        $this->_vinculo = $vinculo;
    }

    public function setCnpjEmpresa($cnpjEmpresa)
    {
        $this->_cnpjEmpresa = $cnpjEmpresa;
    }
}