<?php
namespace HCM\Geral\Repository\Esocial;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class S2200Repository {

    protected  $connection;

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }
    
    public function getItensParaEnvioS2200($params) {
        try {
            $sql = <<<SQL
SELECT VH.NRVINCULOM as NRCHAVE,
       VH.NRVINCULOM,
       '' as NRTABELA,
       'I' as IDOPERACAO,
       GREATEST(NVL(VM.DTESOCIAL,VH.DTMESCOMPETENC),NVL(PE.DTESOCIAL,PH.DTMESCOMPETENC)) as DTMESCOMPETENC
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                      AND VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH H1
                                                WHERE H1.NRVINCULOM = VH.NRVINCULOM
                                                  AND H1.NRORG = VH.NRORG
                                                  AND H1.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTMESCOMPETENC),'YEAR'),-12)
                                                  AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  JOIN GPE_PESSOA PE ON PE.NRORG = VM.NRORG
                    AND PE.NRPESSOA = VM.NRPESSOA
  JOIN GPE_PESSOAH PH ON PH.NRORG = PE.NRORG
                     AND PH.NRPESSOA = PE.NRPESSOA
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                               WHERE H1.NRPESSOA = PH.NRPESSOA
                                                 AND H1.NRORG = PH.NRORG
                                                 AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
 WHERE VM.NRORG = :P_NRORG
   AND VH.NRESTRUTLEGAL = :P_NRESTRUTURAM
   AND VM.DTADMISSAOVINC <= LAST_DAY(:P_DTMESCOMPETENC)
   AND (VM.DTRESCISAOVINC IS NULL OR VM.DTRESCISAOVINC >= NVL(:P_DTRESCISAOVINC,:P_DTMESCOMPETENC))
   AND VM.NRTIPOVINCULOM = 1 /*CLT*/
   AND NOT EXISTS (SELECT 1
                     FROM ESO_ENVIOCADASTROS EC
                     JOIN ESO_EVENTO EV ON EV.NREVENTO = EC.NREVENTO
                                       AND EV.NMEVENTO = 'S-2200'
                     /*VERIFICA EMPRESAS DO MESMO GRUPO - CNPJ RAIZ*/
                     JOIN ESTRUTURAH EVH ON EVH.NRORG = EC.NRORG
                                        AND EVH.NRESTRUTURAM = EC.NRESTRUTURAM
                                        AND SUBSTR(REPLACE(REPLACE(REPLACE(EVH.CDCNPJESTRUT,'.'),'/'),'-'),1,8) = SUBSTR(REPLACE(REPLACE(REPLACE(:P_CDCNPJEMPREGADOR,'.'),'/'),'-'),1,8)
                                        AND EVH.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                                   WHERE H1.NRORG = EVH.NRORG
                                                                     AND H1.NRESTRUTURAM = EVH.NRESTRUTURAM
                                                                     AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                    WHERE EC.NRORG = VM.NRORG
                      AND EC.NRCHAVE = VM.NRVINCULOM
                      AND EC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                      AND (EC.IDSTATUS = 'C' OR EC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                      AND EC.NRENVIOEXCL IS NULL /*QUE NAO FOI EXCLUIDO*/
                      AND EC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                      AND EC.DTMESCOMPETENC <= GREATEST(NVL(VM.DTESOCIAL,VH.DTMESCOMPETENC),NVL(PE.DTESOCIAL,PH.DTMESCOMPETENC))
                      AND NOT EXISTS(SELECT 1
                                       FROM ESO_ENVIOCADASTROS ECC
                                       JOIN ESO_EVENTO EV ON EV.NREVENTO = ECC.NREVENTO
                                                         AND EV.NMEVENTO = 'S-2299'
                                       /*VERIFICA EMPRESAS DO MESMO GRUPO - CNPJ RAIZ*/
                                      WHERE ECC.NRORG = VM.NRORG
                                        AND ECC.NRCHAVE = VM.NRVINCULOM
                                        AND ECC.IDATIVO = 'S' /*QUE ESTIVER ATIVO*/
                                        AND (ECC.IDSTATUS = 'C' OR ECC.IDSTATUS = 'A') /*QUE ESTIVER CONCLUIDO*/
                                        AND ECC.NRENVIOEXCL IS NULL /*QUE NAO FOI EXCLUIDO*/
                                        AND ECC.NRTPAMBIENTE = :P_NRTPAMBIENTE
                                        AND ECC.NRESTRUTURAM = EC.NRESTRUTURAM
                                        AND ECC.DTMESCOMPETENC <= GREATEST(NVL(VM.DTESOCIAL,VH.DTMESCOMPETENC),NVL(PE.DTESOCIAL,PH.DTMESCOMPETENC))))
   AND (VM.NRVINCULOM = :P_NRVINCULOM OR :P_NRVINCULOM IS NULL)
 ORDER BY 1,5
SQL;
            $params = array(
                "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
                "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
                "P_CDCNPJEMPREGADOR" => isset($params['CDCNPJEMPREGADOR']) ? $params['CDCNPJEMPREGADOR'] : null,
                "P_NRESTRUTURAM" => isset($params['NRESTRUTURAM']) ? $params['NRESTRUTURAM'] : null,
                "P_NRTPAMBIENTE" => isset($params['NRTPAMBIENTE']) ? $params['NRTPAMBIENTE'] : null,
                "P_NRVINCULOM" => isset($params['NRVINCULOM']) ? $params['NRVINCULOM'] : null,
                "P_DTRESCISAOVINC" => isset($params['DTRESCISAOVINC']) ? $params['DTRESCISAOVINC'] : null,
            );
            return $this->connection->fetchAll($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getDadosS2200($parametros) {
        try {
            $dataHistorico = \HCM\Util\DateUtil::getDataDeString($parametros['DTMESCOMPETENC'], \HCM\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA, true)->format("d/m/Y");
            
            /* Se for retificação do evento utiliza a data de envio do original para considerar as mesmas situações da época do primeiro envio */
            $dataEnvioOrig = null;
            if ($parametros['IDOPERACAO'] == 'R') {
                $dataEnvioOrig = $parametros['DTRESPOSTAORIG'];
            }
            
            $dados = $this->getDadosPrincipais($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRTPAMBIENTE'], $dataHistorico, $dataEnvioOrig);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosPrincipais($nrenvio, $nrchave, $nrestruturam, $nrtpambiente, $dtmescompetenc, $dataEnvioOrig) {
        $sql = <<<SQL
/*getDadosS2200*/
SELECT VM.NRVINCULOM CHAVE,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') tpInsc,
       CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END nrInsc,
       --trabalhador
       REPLACE(REPLACE(PH.NRCPFPESSOA,'.'),'-') cpfTrab,
       PH.NMPESSOA nmTrab,
       PH.IDSEXOPESSOA sexo,
       RP.CDESOCIAL racaCor,
       EC.CDESOCIAL estCiv,
       GI.CDESOCIAL grauInstr,
       DECODE(VH.NRTPMOVTRANSFM,1,'S','N') indPriEmpr,
       '' nmSoc,
       --nascimento
       TO_CHAR(PH.DTNASCPESSOA,'YYYY-MM-DD') dtNascto,
       PA.CDESOCIAL paisNascto,
       PB.CDESOCIAL paisNac,
       --endereco
       --brasil
       NVL(LG.CDESOCIAL,'O') tpLograd,
       EP.DSENDERECO dscLograd,
       EP.NRIMOVELENDERECO nrLograd,
       SUBSTR(EP.DSCOMPLEENDERECO, 0, 30) complemento,
       EP.NMBAIRROENDERECO bairro,
       REPLACE(REPLACE(REPLACE(EP.NRCEPENDERECO,' '),'.'),'-') cep,
       MP.CDMUNICIBGE brasil_codMunic,
       EP.SGESTADO brasil_uf,
       --exterior
       PC.CDESOCIAL paisResid,
       EE.DSENDERECO exterior_dscLograd,
       EE.NRIMOVELENDERECO exterior_nrLograd,
       SUBSTR(EE.DSCOMPLEENDERECO, 0, 30) exterior_complemento,
       EE.NMBAIRROENDERECO exterior_bairro,
       ME.NMMUNICIPIO nmCid,
       REPLACE(REPLACE(REPLACE(EE.NRCEPENDERECO,' '),'.'),'-') codPostal,
       --trabImig
       DECODE(PB.CDESOCIAL,'105','',DECODE(PH.IDPOSVISTOPERM,'S','2','1')) tmpResid,
       DECODE(PB.CDESOCIAL,'105','','7') condIng,
       --infoDeficiencia
       DECODE(PH.NRCONDFISPES,'2','S','N') defFisica,
       DECODE(PH.NRCONDFISPES,'4','S','N') defVisual,
       DECODE(PH.NRCONDFISPES,'3','S','N') defAuditiva,
       DECODE(PH.NRCONDFISPES,'5','S','N') defMental,
       DECODE(PH.NRCONDFISPES,'8','S','N') defIntelectual,
       DECODE(PH.NRCONDFISPES,'7','S','N') reabReadap,
       NVL(PH.IDCOTAPCD, 'N') infoCota,
       '' observacao,
       --<<dependentes>>-- getDadosS2200dependente
       --contato
       (SELECT REPLACE(REPLACE(REPLACE(REPLACE(REPLACE(MAX(C.CDPREFIXCOMUPARC||C.CDCOMUNICAPARC),' '),'-'),'('),')'),'N/A')
          FROM COMUNICAPARC C
         WHERE C.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
           AND C.NRORG = PE.NRORG
           AND C.CDFORMACOMU = '01') fonePrinc, -- 1-Telefone principal
       (SELECT MAX(C.CDCOMUNICAPARC)
          FROM COMUNICAPARC C
         WHERE C.NRPARCNEGOCIO = PE.NRPARCNEGOCIO
           AND C.NRORG = PE.NRORG
           AND C.CDFORMACOMU = '05') emailPrinc, -- 5-email
       --vinculo
       NVL(VH.CDMATRICULAESOCIAL, VM.NRVINCULOM) matricula,
       '1' tpRegTrab,
       VH.NRTPREGIMEPREV tpRegPrev,
       CASE WHEN NVL(MO.DTINIMOVIMENT,VM.DTADMISSAOVINC) < TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR)) THEN 'S' ELSE 'N' END cadIni,
       --infoRegimeTrab
       --infoCeletista
       TO_CHAR(VM.DTADMISSAOVINC,'YYYY-MM-DD') dtAdm,
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '1', DECODE(SUBSTR(MT.CDCNPJESTRUT,1,8), SUBSTR(PAR.NRINSCRICAOPARC,1,8), '1', '2')), '1') tpAdmissao,
       '1' indAdmissao,
       '' nrProcTrab,
       '1' tpRegJor,
       CASE WHEN VM.NRVINCULOEMPREG IN ('3','4','12','13') THEN '2' ELSE '1' END natAtividade,
       TO_CHAR(ES.DTBASESINDICAL, 'MM') dtBase,
       REPLACE(REPLACE(REPLACE(ES.CDCNPJESTRUT,'.'),'/'),'-') cnpjSindCategProf,
       --FGTS
       CASE WHEN CE.CDESOCIAL IN ('721') THEN TO_CHAR(VM.DTOPCAOFGTS,'YYYY-MM-DD') ELSE NULL END dtOpcFGTS,
       --trabTemporario
       DECODE(CE.CDESOCIAL,'106','2',NULL) hipLeg,
       DECODE(CE.CDESOCIAL,'106','Demada complemetar de serviços',NULL) justContr,
       ----ideEstabVinc
       DECODE(CE.CDESOCIAL,'106',DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF','2',''),NULL) ideEstabVinc_TpInsc,
       DECODE(CE.CDESOCIAL,'106',PN.NRINSCRICAOPARC,NULL) ideEstabVinc_NrInsc,
       --aprendiz
       --infoEstatutario
       --infoContrato
       VH.NRCARGO codCargo,
       VH.NRFUNCAO codFuncao,
       CH.NMOCUPACAOH nmCargo,
       CH.NRCBO CBOCargo,
       '' dtIngrCargo,
       FH.NMOCUPACAOH nmFuncao,
       FH.NRCBO CBOFuncao,
       '' acumCargo,
       CE.CDESOCIAL codCateg,
       --remuneracao
       DECODE(SL.IDTPSALARIO,'HORA', ROUND(SL.VRSALARIO / (EH.QTHRESCALATRABH * 30), 2), ROUND(SL.VRSALARIO, 2)) vrSalFx,
       DECODE(SL.IDTPSALARIO,'HORA','1','DIARIO','2','SEMANAL','3','QUINZENAL','4','MENSAL','5','TAREFA','6','7') undSalFixo,
       SUBSTR(SL.DSOBSERVACAO,1,90) dscSalVar,
       --duracao
       CASE
        WHEN MO.NRTPMOVTRANSFM = 8 AND MT.CDCNPJESTRUT IS NOT NULL AND SUBSTR(MT.CDCNPJESTRUT,1,8) <> SUBSTR(PAR.NRINSCRICAOPARC,1,8) THEN '1'
        ELSE CASE WHEN VM.NRVINCULOEMPREG IN (2, 3, 10, 11, 12, 13) OR (VM.NRVINCULOEMPREG = 1 AND VM.DTVENCCONTREXPER IS NOT NULL) THEN '2' ELSE '1' END
       END tpContr,
       CASE
        WHEN MO.NRTPMOVTRANSFM = 8 AND MT.CDCNPJESTRUT IS NOT NULL AND SUBSTR(MT.CDCNPJESTRUT,1,8) <> SUBSTR(PAR.NRINSCRICAOPARC,1,8) THEN ''
        ELSE CASE WHEN VM.NRVINCULOEMPREG IN (2, 3, 10, 11, 12, 13) OR (VM.NRVINCULOEMPREG = 1 AND VM.DTVENCCONTREXPER IS NOT NULL) THEN TO_CHAR(VH.DTFIMCONTRDETERMIN,'YYYY-MM-DD') ELSE '' END
       END dtTerm,
       CASE
        WHEN MO.NRTPMOVTRANSFM = 8 AND MT.CDCNPJESTRUT IS NOT NULL AND SUBSTR(MT.CDCNPJESTRUT,1,8) <> SUBSTR(PAR.NRINSCRICAOPARC,1,8) THEN ''
        ELSE CASE WHEN VM.NRVINCULOEMPREG IN (2, 3, 10, 11, 12, 13) OR (VM.NRVINCULOEMPREG = 1 AND VM.DTVENCCONTREXPER IS NOT NULL) THEN 'N' ELSE '' END
       END clauAssec, --v_2.4.01
       '' objDet,
       --localTrabalho
       --localTrabGeral
       DECODE(CE.CDESOCIAL,'106',NULL,DECODE(PN.CDTIPOINSCRICAO,'CNPJ','1','CPF',DECODE(ET.CDCAEPFESTRUT,NULL,'2','3'),'')) localTrabGeral_TpInsc,
       DECODE(CE.CDESOCIAL,'106',NULL,DECODE(PN.CDTIPOINSCRICAO,'CPF',DECODE(ET.CDCAEPFESTRUT,NULL,PN.NRINSCRICAOPARC,ET.CDCAEPFESTRUT),PN.NRINSCRICAOPARC)) localTrabGeral_NrInsc,
       DECODE(CE.CDESOCIAL,'106',NULL,PN.NMPRINCIPALPARC) descComp,
       --localTrabDom
       DECODE(CE.CDESOCIAL,'106',NVL(LGD.CDESOCIAL,'O'),NULL) localTrabDom_TpLograd,
       DECODE(CE.CDESOCIAL,'106',EPD.DSENDERECO,NULL) localTrabDom_DscLograd,
       DECODE(CE.CDESOCIAL,'106',EPD.NRIMOVELENDERECO,NULL) localTrabDom_NrLograd,
       DECODE(CE.CDESOCIAL,'106',SUBSTR(EPD.DSCOMPLEENDERECO, 0, 30),NULL) localTrabDom_Complemento,
       DECODE(CE.CDESOCIAL,'106',EPD.NMBAIRROENDERECO,NULL) localTrabDom_Bairro,
       DECODE(CE.CDESOCIAL,'106',REPLACE(REPLACE(REPLACE(EPD.NRCEPENDERECO,' '),'.'),'-'),NULL) localTrabDom_Cep,
       DECODE(CE.CDESOCIAL,'106',MPD.CDMUNICIBGE,NULL) localTrabDom_CodMunic,
       DECODE(CE.CDESOCIAL,'106',EPD.SGESTADO,NULL) localTrabDom_Uf,
       --horContratual
       EH.QTHRSEMESCTRABH qtdHrsSem,
       TJ.CDESOCIAL AS tpJornada,
       '0' tmpParc,
       NVL(EH.IDHORNOTURNO,'N') horNoturno,
       EH.NMESCALATRABH dscJorn,
       --alvaraJudicial
       '' nrProcJud,
       --alvaraJudicial
       --observacoes
       --treiCap
       --sucessaoVinc
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '', DECODE(MT.CDTIPOINSCRICAO,'CNPJ','1','CPF','2',''))) sucessaoVinc_tpInsc,
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '', DECODE(SUBSTR(MT.CDCNPJESTRUT,1,8), SUBSTR(PAR.NRINSCRICAOPARC,1,8), '', REPLACE(REPLACE(REPLACE(MT.CDCNPJESTRUT,'.'),'/'),'-'))), '') sucessaoVinc_nrInsc,
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '', DECODE(SUBSTR(MT.CDCNPJESTRUT,1,8), SUBSTR(PAR.NRINSCRICAOPARC,1,8), '', VM.NRVINCULOM)), '') matricAnt,
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '', DECODE(SUBSTR(MT.CDCNPJESTRUT,1,8), SUBSTR(PAR.NRINSCRICAOPARC,1,8), '', TO_CHAR(MO.DTINIMOVIMENT, 'YYYY-MM-DD'))), '') dtTransf,
       DECODE(MO.NRTPMOVTRANSFM, 8, DECODE(MT.CDCNPJESTRUT, NULL, '', DECODE(SUBSTR(MT.CDCNPJESTRUT,1,8), SUBSTR(PAR.NRINSCRICAOPARC,1,8), '', SUBSTR(MO.DSOBSERVACAO,1,255))), '') sucessaoVinc_Observacao,
       --mudancaCPF
       --afastamento
       TO_CHAR(
        CASE
            WHEN SF.DTINISITUFUNC IS NULL AND GO.DTINIGOZOFERIAS IS NULL THEN NULL  /*Situacao Normal*/
            WHEN GO.DTINIGOZOFERIAS < SF.DTINISITUFUNC OR SF.DTINISITUFUNC IS NULL THEN GO.DTINIGOZOFERIAS  /*Em ferias*/
            WHEN SF.DTINISITUFUNC < GO.DTINIGOZOFERIAS OR GO.DTINIGOZOFERIAS IS NULL THEN SF.DTINISITUFUNC  /*Afastado*/
            ELSE NULL
        END,
       'YYYY-MM-DD') dtIniAfast,
       CASE
        WHEN SF.DTINISITUFUNC IS NULL AND GO.DTINIGOZOFERIAS IS NULL THEN ''  /*Situacao Normal*/
        WHEN GO.DTINIGOZOFERIAS < SF.DTINISITUFUNC OR SF.DTINISITUFUNC IS NULL THEN '15'  /*Em ferias*/
        WHEN SF.DTINISITUFUNC < GO.DTINIGOZOFERIAS OR GO.DTINIGOZOFERIAS IS NULL THEN MA.CDESOCIAL  /*Afastado*/
        ELSE ''
       END codMotAfast,
       --desligamento
       CASE WHEN VM.DTRESCISAOVINC < TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR)) THEN TO_CHAR(VM.DTRESCISAOVINC,'YYYY-MM-DD') ELSE NULL END dtDeslig,
       VM.NRVINCULOM, PE.NRORG, PE.NRPARCNEGOCIO, EH.NRESCALATRABM, AE.NRTURNO
  FROM GPE_VINCULOM VM
  JOIN GPE_VINCULOEMPREG VE ON VE.NRVINCULOEMPREG = VM.NRVINCULOEMPREG
  LEFT JOIN GPE_CATEGTRABESOC CE ON CE.NRCATEGESOC = VE.NRCATEGESOC
  JOIN GPE_TIPOVINCULOH VT ON VT.NRTIPOVINCULOM = VM.NRTIPOVINCULOM
                          AND (VT.NRORG = VM.NRORG OR VT.NRORG = 0 OR VT.NRORG IS NULL)
                          AND VT.IDVINCULOEMPR = 'S'
                          AND VT.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_TIPOVINCULOH
                                                    WHERE GPE_TIPOVINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                      AND GPE_TIPOVINCULOH.NRTIPOVINCULOM = VT.NRTIPOVINCULOM
                                                      AND GPE_TIPOVINCULOH.NRORG = VT.NRORG)
  JOIN GPE_VINCULOH VH ON VH.NRVINCULOM = VM.NRVINCULOM
                      AND VH.NRORG = VM.NRORG
                      AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                WHERE GPE_VINCULOH.DTMESCOMPETENC <= :P_DTHISTORICO
                                                  AND GPE_VINCULOH.DTMESCOMPETENC >= ADD_MONTHS(TRUNC(TO_DATE(:P_DTHISTORICO),'YEAR'),-12)
                                                  AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                  AND GPE_VINCULOH.NRORG = VH.NRORG)
  
  /*Empregador*/
  JOIN ESTRUTURAM EMP ON EMP.NRORG = :P_NRORG
                     AND EMP.NRESTRUTURAM = :P_NRESTRUTURAM
  
  JOIN ESTRUTURAH EMH ON EMH.NRORG = EMP.NRORG
                     AND EMH.NRESTRUTURAM = EMP.NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                WHERE DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                  AND NRESTRUTURAM = EMH.NRESTRUTURAM
                                                  AND NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*Local de Trabalho*/
  JOIN ESTRUTURAH ET ON ET.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND ET.NRORG = VH.NRORG
                    AND ET.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                              WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                AND ESTRUTURAH.NRESTRUTURAM = ET.NRESTRUTURAM
                                                AND ESTRUTURAH.NRORG = ET.NRORG)
  JOIN PARCNEGOCIO PN ON PN.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                     AND PN.NRORG = ET.NRORG
  /*Tomador de Serviços*/
  LEFT JOIN TIPOHIERARQORG TH ON (TH.NRORG = VM.NRORG OR TH.NRORG = 0)
                             AND TH.NRTIPOESTRUTREL = :P_NRTIPOESTRUTGEREN
                             AND TH.NRTIPOESTRUTSUP = NVL(:P_NRTIPOESTRUTOMADOR, 7)
  LEFT JOIN HIERARQUIAORG HO ON HO.NRORG = VM.NRORG
                            AND HO.NRTIPOHIERARQORG = TH.NRTIPOHIERARQORG
                            AND HO.NRESTRUTURAMREL = VH.NRESTRUTGEREN
                            AND HO.DTINIVIGENCIA = (SELECT MAX(DTINIVIGENCIA)
                                                      FROM HIERARQUIAORG HI
                                                     WHERE HI.NRORG = HO.NRORG
                                                       AND HI.NRESTRUTURAMREL = HO.NRESTRUTURAMREL
                                                       AND HI.NRTIPOHIERARQORG = HO.NRTIPOHIERARQORG
                                                       AND HI.DTINIVIGENCIA <= :P_DTMESCOMPETENC)
                            AND (HO.DTFIMVIGENCIA >= LAST_DAY(:P_DTMESCOMPETENC) OR HO.DTFIMVIGENCIA IS NULL)
  LEFT JOIN ESTRUTURAM EMT ON EMT.NRESTRUTURAM = HO.NRESTRUTURAMSUP
                          AND EMT.NRORG = HO.NRORG
  LEFT JOIN ESTRUTURAH EHT ON EHT.NRESTRUTURAM = EMT.NRESTRUTURAM
                          AND EHT.NRORG = EMT.NRORG
                          AND EHT.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                     WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                       AND ESTRUTURAH.NRESTRUTURAM = EHT.NRESTRUTURAM
                                                       AND ESTRUTURAH.NRORG = EHT.NRORG)
  LEFT JOIN PARCNEGOCIO PNT ON PNT.NRPARCNEGOCIO = EHT.NRPARCNEGOCIO
                           AND PNT.NRORG = EHT.NRORG
  /*Endereço Trabalho Domestico*/
  LEFT JOIN ENDERECOPARC EPD ON EPD.NRPARCNEGOCIO = NVL(PNT.NRPARCNEGOCIO,PN.NRPARCNEGOCIO)
                            AND EPD.NRORG = NVL(PNT.NRORG,PN.NRORG)
                            AND EPD.CDTIPOENDERECO = 'PRINCIPAL'
  LEFT JOIN MUNICIPIO MPD ON MPD.CDPAIS = EPD.CDPAIS
                         AND MPD.SGESTADO = EPD.SGESTADO
                         AND MPD.CDMUNICIPIO = EPD.CDMUNICIPIO
  LEFT JOIN LOGRADOURO LGD ON LGD.CDLOGRADOURO = EPD.CDLOGRADOURO
                         AND (LGD.NRORG = EPD.NRORG OR LGD.NRORG = 0)
  /*Dados do Empregado - Dependentes*/
  JOIN GPE_PESSOA PE ON VM.NRPESSOA = PE.NRPESSOA
                    AND VM.NRORG    = PE.NRORG
  JOIN GPE_PESSOAH PH ON PE.NRPESSOA = PH.NRPESSOA
                     AND PE.NRORG    = PH.NRORG
                     AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                               WHERE GPE_PESSOAH.DTMESCOMPETENC <= :P_DTHISTORICO
                                                 AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                 AND GPE_PESSOAH.NRORG = PH.NRORG)
  /*Dados do Empregado - Naturalidade*/
  LEFT JOIN PAIS PA ON PA.CDPAIS = PH.CDPAIS
  LEFT JOIN GPE_NACIONALIDADE NA ON PH.NRNACIONALID = NA.NRNACIONALIDADE
                                AND (PH.NRORG = NA.NRORG OR NA.NRORG = 0)
  LEFT JOIN PAIS PB ON PB.CDPAIS = NA.CDPAIS
  /*Endereço Principal*/
  LEFT JOIN ENDERECOPARC EP ON PE.NRPARCNEGOCIO = EP.NRPARCNEGOCIO
                           AND PE.NRORG = EP.NRORG
                           AND EP.CDTIPOENDERECO = 'PRINCIPAL'
  LEFT JOIN MUNICIPIO MP ON MP.CDPAIS = EP.CDPAIS
                        AND MP.SGESTADO = EP.SGESTADO
                        AND MP.CDMUNICIPIO = EP.CDMUNICIPIO
  /*Endereço Exterior*/
  LEFT JOIN ENDERECOPARC EE ON PE.NRPARCNEGOCIO = EE.NRPARCNEGOCIO
                           AND PE.NRORG = EE.NRORG
                           AND EE.CDTIPOENDERECO = 'EXTERIOR'
  LEFT JOIN MUNICIPIO ME ON ME.CDPAIS = EE.CDPAIS
                        AND ME.SGESTADO = EE.SGESTADO
                        AND ME.CDMUNICIPIO = EE.CDMUNICIPIO
  LEFT JOIN PAIS PC ON PC.CDPAIS = EE.CDPAIS
  /*Movimentacao*/
  LEFT JOIN (SELECT MO.NRORG, MO.NRVINCULOM, MO.NRESTRUTURAM, MO.NRTPMOVTRANSFM, MO.DTINIMOVIMENT, MO.DSOBSERVACAO, ET.CDCNPJESTRUT
               FROM GPE_MOVIMENTACAO MO
               JOIN ESTRUTURAH ET ON ET.NRORG = MO.NRORG
                                 AND ET.NRESTRUTURAM = MO.NRESTRUTURAM
                                 AND ET.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = ET.NRORG
                                                             AND H1.NRESTRUTURAM = ET.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC < :P_DTMESCOMPETENC)
              WHERE MO.NRORG = :P_NRORG
                AND MO.NRVINCULOM = :P_NRCHAVE
                AND MO.NRTPMOVTRANSFM = 8
                AND MO.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL) MO ON MO.NRORG = VH.NRORG
                                                                 AND MO.NRVINCULOM = VH.NRVINCULOM
                                                                 AND SUBSTR(MO.CDCNPJESTRUT,1,8) = SUBSTR(PAR.NRINSCRICAOPARC,1,8)
                                                                 AND MO.DTINIMOVIMENT = (SELECT MIN(M1.DTINIMOVIMENT) FROM GPE_MOVIMENTACAO M1
                                                                                           JOIN ESTRUTURAH H1 ON H1.NRORG = M1.NRORG
                                                                                                             AND H1.NRESTRUTURAM = M1.NRESTRUTURAM
                                                                                                             AND H1.DTMESCOMPETENC = (SELECT MAX(H2.DTMESCOMPETENC) FROM ESTRUTURAH H2
                                                                                                                                       WHERE H2.NRORG = H1.NRORG
                                                                                                                                         AND H2.NRESTRUTURAM = H1.NRESTRUTURAM
                                                                                                                                         AND H2.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                                                                                          WHERE M1.NRORG = MO.NRORG
                                                                                            AND M1.NRVINCULOM = MO.NRVINCULOM
                                                                                            AND SUBSTR(H1.CDCNPJESTRUT,1,8) = SUBSTR(PAR.NRINSCRICAOPARC,1,8)
                                                                                            AND M1.NRTPMOVTRANSFM = 8
                                                                                            AND M1.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL
                                                                                            AND M1.DTINIMOVIMENT < LAST_DAY(:P_DTMESCOMPETENC))
  /*Movimentacao Anterior*/
  LEFT JOIN (SELECT MT.NRORG, MT.NRVINCULOM, MT.NRESTRUTURAM, MT.DTINIMOVIMENT, ET.CDCNPJESTRUT, ETP.CDTIPOINSCRICAO
               FROM GPE_MOVIMENTACAO MT
               JOIN ESTRUTURAH ET ON ET.NRORG = MT.NRORG
                                 AND ET.NRESTRUTURAM = MT.NRESTRUTURAM
                                 AND ET.DTMESCOMPETENC = (SELECT MAX(H1.DTMESCOMPETENC) FROM ESTRUTURAH H1
                                                           WHERE H1.NRORG = ET.NRORG
                                                             AND H1.NRESTRUTURAM = ET.NRESTRUTURAM
                                                             AND H1.DTMESCOMPETENC < :P_DTMESCOMPETENC)
               JOIN PARCNEGOCIO ETP ON ETP.NRPARCNEGOCIO = ET.NRPARCNEGOCIO
                                   AND ETP.NRORG = ET.NRORG
              WHERE MT.NRORG = :P_NRORG
                AND MT.NRVINCULOM = :P_NRCHAVE
                AND MT.NRESTRUTURAM <> :P_NRESTRUTURAM
                AND MT.NRTIPOTRANSFER = 1
                AND MT.NRTPMOVTRANSFM <> 9
                AND MT.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL) MT ON MT.NRORG = VH.NRORG
                                                                 AND MT.NRVINCULOM = VH.NRVINCULOM
                                                                 AND SUBSTR(MT.CDCNPJESTRUT,1,8) <> SUBSTR(PAR.NRINSCRICAOPARC,1,8)
                                                                 AND MT.DTINIMOVIMENT = (SELECT MAX(M1.DTINIMOVIMENT) FROM GPE_MOVIMENTACAO M1
                                                                                           JOIN ESTRUTURAH H1 ON H1.NRORG = M1.NRORG
                                                                                                             AND H1.NRESTRUTURAM = M1.NRESTRUTURAM
                                                                                                             AND H1.DTMESCOMPETENC = (SELECT MAX(H2.DTMESCOMPETENC) FROM ESTRUTURAH H2
                                                                                                                                       WHERE H2.NRORG = H1.NRORG
                                                                                                                                         AND H2.NRESTRUTURAM = H1.NRESTRUTURAM
                                                                                                                                         AND H2.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
                                                                                          WHERE M1.NRORG = MT.NRORG
                                                                                            AND M1.NRVINCULOM = MT.NRVINCULOM
                                                                                            AND SUBSTR(H1.CDCNPJESTRUT,1,8) <> SUBSTR(PAR.NRINSCRICAOPARC,1,8)
                                                                                            AND M1.NRTIPOTRANSFER = 1
                                                                                            AND M1.NRTPMOVTRANSFM <> 9
                                                                                            AND M1.NRTIPOESTRUTURA = :P_NRTIPOESTRUTLEGAL
                                                                                            AND M1.DTINIMOVIMENT < MO.DTINIMOVIMENT)
  /*Cargo*/
  LEFT JOIN GPE_OCUPACAOH CH ON CH.NROCUPACAOM = VH.NRCARGO
                            AND CH.NRORG = VH.NRORG
                            AND CH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH
                                                      WHERE GPE_OCUPACAOH.DTMESCOMPETENC <= LAST_DAY(:P_DTMESCOMPETENC)
                                                        AND GPE_OCUPACAOH.NROCUPACAOM = CH.NROCUPACAOM
                                                        AND GPE_OCUPACAOH.NRORG = CH.NRORG)
  /*Função*/
  LEFT JOIN GPE_OCUPACAOH FH ON FH.NROCUPACAOM = VH.NRFUNCAO
                            AND FH.NRORG = VH.NRORG
                            AND FH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_OCUPACAOH
                                                      WHERE GPE_OCUPACAOH.DTMESCOMPETENC <= LAST_DAY(:P_DTMESCOMPETENC)
                                                        AND GPE_OCUPACAOH.NROCUPACAOM = FH.NROCUPACAOM
                                                        AND GPE_OCUPACAOH.NRORG = FH.NRORG)
  /*Salário*/
  LEFT JOIN GPE_ALTESALARIO SL ON SL.NRVINCULOM = VM.NRVINCULOM
                              AND SL.NRORG = VM.NRORG
                              AND SL.DTALTESALARIO = (SELECT MAX(DTALTESALARIO) FROM GPE_ALTESALARIO
                                                       WHERE GPE_ALTESALARIO.DTALTESALARIO <= LAST_DAY(:P_DTMESCOMPETENC)
                                                         AND GPE_ALTESALARIO.NRVINCULOM = SL.NRVINCULOM
                                                         AND GPE_ALTESALARIO.NRORG = SL.NRORG)
                              AND SL.NROCORRENCIA =  (SELECT MAX(NROCORRENCIA) FROM GPE_ALTESALARIO
                                                       WHERE GPE_ALTESALARIO.DTALTESALARIO = SL.DTALTESALARIO
                                                         AND GPE_ALTESALARIO.NRVINCULOM = SL.NRVINCULOM
                                                         AND GPE_ALTESALARIO.NRORG = SL.NRORG)
  /*Horário*/
  LEFT JOIN GPE_ALTEESCALA AE ON AE.NRORG = VH.NRORG
                             AND AE.NRVINCULOM = VH.NRVINCULOM
                             AND (AE.DTFIMESCALA IS NULL OR AE.DTFIMESCALA > LAST_DAY(:P_DTMESCOMPETENC) OR VM.DTRESCISAOVINC IS NOT NULL)
                             AND AE.DTINIESCALA = (SELECT MAX(DTINIESCALA) FROM GPE_ALTEESCALA
                                                    WHERE GPE_ALTEESCALA.DTINIESCALA <= LAST_DAY(:P_DTMESCOMPETENC)
                                                      AND (GPE_ALTEESCALA.DTFIMESCALA IS NULL OR GPE_ALTEESCALA.DTFIMESCALA > LAST_DAY(:P_DTMESCOMPETENC) OR VM.DTRESCISAOVINC IS NOT NULL)
                                                      AND GPE_ALTEESCALA.NRVINCULOM = AE.NRVINCULOM
                                                      AND GPE_ALTEESCALA.NRORG = AE.NRORG)
  LEFT JOIN GPE_ESCALATRABH EH ON EH.NRESCALATRABM = AE.NRESCALATRABM
                              AND EH.NRORG = AE.NRORG
                              AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_ESCALATRABH
                                                        WHERE GPE_ESCALATRABH.DTMESCOMPETENC <= LAST_DAY(:P_DTMESCOMPETENC)
                                                          AND GPE_ESCALATRABH.NRESCALATRABM = EH.NRESCALATRABM
                                                          AND GPE_ESCALATRABH.NRORG = EH.NRORG)
  LEFT JOIN PTO_TIPOJORNADA TJ ON TJ.NRTPJORNADA = EH.NRTPJORNADA
                              AND (TJ.NRORG = EH.NRORG OR TJ.NRORG = 0)
  /*Afastamento - Situacao Funcional*/
  LEFT JOIN (SELECT SF.NRORG, SF.NRVINCULOM, SF.DTINISITUFUNC, SF.DTFIMSITUFUNC, SF.NRMOTIVOAFASTA
               FROM GPE_ALTESITUFUNC SF
               JOIN GPE_SITUFUNCH SFH ON SFH.NRSITUFUNCM = SF.NRSITUFUNCM
                                     AND SFH.DTEFETIVA = (SELECT MAX(DTEFETIVA) FROM GPE_SITUFUNCH
                                                           WHERE GPE_SITUFUNCH.DTEFETIVA <= :P_DTMESCOMPETENC
                                                             AND GPE_SITUFUNCH.NRSITUFUNCM = SFH.NRSITUFUNCM
                                                             AND GPE_SITUFUNCH.NRORG = SFH.NRORG)
              WHERE SF.NRORG = :P_NRORG
                AND SF.NRVINCULOM = :P_NRCHAVE
                AND ((:P_DTENVIOORIG BETWEEN SF.DTINISITUFUNC AND NVL(SF.DTFIMSITUFUNC,:P_DTENVIOORIG)) OR :P_DTENVIOORIG IS NULL) /*P_DTENVIOORIG para casos de retificacao*/
                AND (SFH.IDAFASTSITUFUNC = 'S' /*Situacao funcional que gere afastamento*/
                     OR SF.NRSITUFUNCM = 12 OR SF.NRSITUFUNCM = 100012 OR SF.NRSITUFUNCM = 15 OR SF.NRSITUFUNCM = 16) /*Atestados médico e odontológico, Afastamentos 15 dias empregador*/
                AND SF.NRSITUFUNCM <> 13 /*Demitito eh parametrizado como gera afastamento mas nao gera o evento*/
             ) SF ON SF.NRVINCULOM = VH.NRVINCULOM
                 AND SF.NRORG = VH.NRORG
                 AND SF.DTINISITUFUNC < TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR))
                 AND (SF.DTFIMSITUFUNC >= TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR)) OR SF.DTFIMSITUFUNC IS NULL)
  /*Motivo Afastamento*/
  LEFT JOIN GPE_MOTIVOAFASTA MA ON MA.NRMOTIVOAFASTA = SF.NRMOTIVOAFASTA
                               AND (MA.NRORG = SF.NRORG OR MA.NRORG = 0)
  /*Afastamento - Ferias*/
  LEFT JOIN (SELECT FE.NRORG, FE.NRVINCULOM, GO.DTINIGOZOFERIAS, GO.DTFIMGOZOFERIAS
               FROM FPA_FERIAS FE
               JOIN FPA_GOZOFERIAS GO ON GO.NRORG = FE.NRORG
                                     AND GO.NRFERIAS = FE.NRFERIAS
              WHERE FE.NRORG = :P_NRORG
                AND FE.NRVINCULOM = :P_NRCHAVE
                AND ((:P_DTENVIOORIG BETWEEN GO.DTINIGOZOFERIAS AND NVL(GO.DTFIMGOZOFERIAS,:P_DTENVIOORIG) ) OR :P_DTENVIOORIG IS NULL) /*P_DTENVIOORIG para casos de retificacao*/
             ) GO ON GO.NRORG = VH.NRORG
                 AND GO.NRVINCULOM = VH.NRVINCULOM
                 AND GO.DTINIGOZOFERIAS < TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR))
                 AND (GO.DTFIMGOZOFERIAS >= TO_DATE(DECODE(:P_NRTPAMBIENTE, 1, DECODE(EMP.NRGRUPOESOCIAL, 3, :P_INIVALIDADEAMBNS, :P_INIVALIDADEAMBP), 2, :P_INIVALIDADEAMBPR)) OR GO.DTFIMGOZOFERIAS IS NULL)
  /*Sindicato*/
  LEFT JOIN ESTRUTURAH ES ON ES.NRESTRUTURAM = VH.NRESTRUTSIND
                         AND ES.NRORG = VH.NRORG
                         AND ES.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                   WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                     AND ESTRUTURAH.NRESTRUTURAM = ES.NRESTRUTURAM
                                                     AND ESTRUTURAH.NRORG = ES.NRORG)
  /*RaçaCor*/
  LEFT JOIN GPE_RACAPESSOA RP ON RP.NRRACAPESSOA = PH.NRRACAPESSOA
                             AND (RP.NRORG = PH.NRORG OR RP.NRORG = 0)
  /*Estado Civil*/
  LEFT JOIN ESTADOCIVIL EC ON EC.CDESTACIVIL = PH.CDESTACIVIL
                          AND (EC.NRORG = PH.NRORG OR EC.NRORG = 0)
  /*Grau Instrução*/
  LEFT JOIN GPE_GRAUINSTR GI ON GI.NRGRAUINSTR = PH.NRGRAUINSTR
                            AND (GI.NRORG = PH.NRORG OR GI.NRORG = 0)
  /*Logradouro*/
  LEFT JOIN LOGRADOURO LG ON LG.CDLOGRADOURO = EP.CDLOGRADOURO
                         AND (LG.NRORG = EP.NRORG OR LG.NRORG = 0)
  /*Parametro do eSocial*/
  LEFT JOIN ESO_PARAMETRO PARAM ON PARAM.NRORG = :P_NRORG
                            AND PARAM.NRESTRUTURAM = :P_NRESTRUTURAM
                            AND PARAM.DTINIVIGENCIA <= :P_DTMESCOMPETENC
                            AND (PARAM.DTFIMVIGENCIA IS NULL OR PARAM.DTFIMVIGENCIA >= :P_DTMESCOMPETENC)
 WHERE VM.NRORG = :P_NRORG
   AND VM.NRTIPOVINCULOM = 1 --CLT
   AND VM.NRVINCULOM = :P_NRCHAVE
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRTIPOESTRUTLEGAL" => $this->hcmParameters->getTipoEstruturaLegalOrg(),
            "P_NRTIPOESTRUTGEREN" => $this->hcmParameters->getTipoEstruturaGerencialOrg(),
            "P_NRTIPOESTRUTOMADOR" => $this->hcmParameters->getTipoEstruturaTomadorOrg(),
            "P_NRTPAMBIENTE" => $nrtpambiente,
            "P_INIVALIDADEAMBPR" => $this->hcmParameters->getEsoIniValidNaoPerProdRest(),
            "P_INIVALIDADEAMBP" => $this->hcmParameters->getEsoIniValidNaoPerProducao(),
            "P_INIVALIDADEAMBNS" => $this->hcmParameters->getEsoIniValidNaoPerNacioSimples(),
            "P_NRENVIO" => $nrenvio,
            "P_NRCHAVE" => $nrchave,
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_DTHISTORICO" => $dtmescompetenc,
            "P_DTENVIOORIG" => $dataEnvioOrig,
        );
        return $this->connection->fetchAssoc($sql, $params);
    }

    public function getDadosS2200dependente($parametros) {
        try {
            $dados = $this->getDadosdependente($parametros['NRORG'], $parametros['NRPARCNEGOCIO'], $parametros['NRVINCULOM']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }

    public function getDadosdependente($nrorg, $nrparcnegocio, $nrvinculom) {
        $sql = <<<SQL
/*getDadosS2200dependente*/
SELECT LPAD(T.CDESOCIAL,2,'0') tpDep,
       H.NMPESSOA nmDep,
       TO_CHAR(H.DTNASCPESSOA,'YYYY-MM-DD') dtNascto,
       REPLACE(REPLACE(H.NRCPFPESSOA, '.'), '-') cpfDep,
       H.IDSEXOPESSOA sexoDep,
       DECODE((SELECT NVL(COUNT(*),0) FROM FPA_DEPVINCULO WHERE NRVINCULOM = :P_NRVINCULOM AND NRPESSOA = P.NRPESSOA AND NRORG = P.NRORG AND NRTIPODEPENDE = '2'),0,'N','S') depIRRF,
       DECODE((SELECT NVL(COUNT(*),0) FROM FPA_DEPVINCULO WHERE NRVINCULOM = :P_NRVINCULOM AND NRPESSOA = P.NRPESSOA AND NRORG = P.NRORG AND NRTIPODEPENDE = '1'),0,'N','S') depSF,
       DECODE(NVL(H.NRCONDFISPES,1),1,'N','S') incTrab
  FROM RELACIONAPARC R
  JOIN TIPORELACIONA T ON (T.NRORG = R.NRORG OR T.NRORG = 0)
                      AND T.NRTIPORELACIONA = R.NRTIPORELACIONA
  JOIN GPE_PESSOA P ON R.NRPARCNEGRELAC = P.NRPARCNEGOCIO
                   AND R.NRORG = P.NRORG
                   AND EXISTS (SELECT 1 FROM FPA_DEPVINCULO D
                                WHERE D.NRPESSOA = P.NRPESSOA
                                  AND D.NRORG = P.NRORG
                                  AND D.NRVINCULOM = :P_NRVINCULOM)
  JOIN GPE_PESSOAH H ON P.NRPESSOA = H.NRPESSOA
                    AND P.NRORG = H.NRORG
                    AND H.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH H1
                                             WHERE H1.NRPESSOA = P.NRPESSOA
                                               AND H1.NRORG = P.NRORG
                                               AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
 WHERE R.NRPARCNEGOCIO = :P_NRPARCNEGOCIO
   AND R.NRORG = :P_NRORG
SQL;
        $params = array(
            "P_NRORG" => $nrorg,
            "P_NRPARCNEGOCIO" => $nrparcnegocio,
            "P_NRVINCULOM" => $nrvinculom,
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
        );
        return $this->connection->fetchAll($sql, $params);
    }

}