<?php
namespace HCM\Geral\Repository\Esocial;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;

class S3000Repository {

    protected  $connection;

    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }

    public function getDadosS3000($parametros) {
        try {
            $dados = $this->getDadosPrincipais($parametros['NRENVIO'], $parametros['NRCHAVE'], $parametros['NRESTRUTURAM'], $parametros['NRENVIOORIG'], $parametros['NRIDETRABALHADOR'], $parametros['NRIDEFOLHAPGTO']);
            return $dados;
        } catch(\Exception $e) {
            throw $e;
        }
    }
    
    public function getDadosPrincipais($nrenvio, $nrchave, $nrestruturam, $nrenvioorig, $nrIdeTrabalhador, $nrIdeFolhaPgto) {
        $sql = <<<SQL
/*getDadosS3000*/
SELECT EC.NRCHAVE CHAVE,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,   
       --infoExclusao
       EC.NMEVENTO tpEvento,
       EC.NRRECIBO nrRecEvt,
       --ideTrabalhador
       REPLACE(REPLACE(PH.NRCPFPESSOA,'.'),'-') cpfTrab,
       --ideFolhaPagto
       DECODE(EC.NMEVENTO, 'S-1250', EC.NRTABELA, 'S-1210', '', DECODE(CF.NRTIPOMOVIMENT,1,'1',2,'1',4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','2','1'),10,'1',19,'1','')) indApuracao,
       DECODE(EC.NMEVENTO, 'S-1250', TO_CHAR(EC.DTMESCOMPETENC,'YYYY-MM'), 'S-1210', TO_CHAR(EC.DTMESCOMPETENC,'YYYY-MM'), TO_CHAR(DECODE(EC.NMEVENTO,'S-1210',IC.DTOCORRENCIA,CF.DTOCORRENCIA), DECODE(CF.NRTIPOMOVIMENT,4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','YYYY','YYYY-MM'),'YYYY-MM'))) perApur
  FROM ESO_NAOPERIODICO EC
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*ideTrabalhador*/
  LEFT JOIN GPE_PESSOAH PH ON PH.NRORG = EC.NRORG
                          AND PH.NRPESSOA = :P_NRIDETRABALHADOR
                          AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                                    WHERE GPE_PESSOAH.NRORG = PH.NRORG
                                                      AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                      AND GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN GPE_VINCULOM VM ON VM.NRORG = PH.NRORG
                           AND VM.NRPESSOA = PH.NRPESSOA
  LEFT JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                           AND VH.NRVINCULOM = VM.NRVINCULOM
                           AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                    WHERE GPE_VINCULOH.NRORG = VH.NRORG
                                                      AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                      AND GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*ideFolhaPagto*/
  LEFT JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = EC.NRORG
                               AND CF.NRCALCULOFOLHA = :P_NRIDEFOLHAPAGTO
  LEFT JOIN FPA_ITECALCFOLHA IC ON IC.NRORG = CF.NRORG
                               AND IC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                               AND IC.NRVINCULOM = VM.NRVINCULOM
                               AND IC.NREVENTOM IN (3030,3050)
 WHERE EC.NRORG = :P_NRORG
   AND EC.NRENVIO = :P_NRENVIOORIG
   AND (((SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(PAR.NRINSCRICAOPARC,1,8) OR EC.NMEVENTO = 'S-2190') AND :P_NRIDETRABALHADOR IS NOT NULL) OR (:P_NRIDETRABALHADOR IS NULL))
UNION ALL
SELECT EC.NRCHAVE CHAVE,
       --ideEmpregador
       DECODE(PAR.CDTIPOINSCRICAO,'CNPJ','1','CPF','2','') TPINSC,
       CASE WHEN PAR.CDTIPOINSCRICAO = 'CPF' OR EMH.CDNATUJURI IN ('1015','1040','1074','1163') THEN PAR.NRINSCRICAOPARC ELSE SUBSTR(PAR.NRINSCRICAOPARC,1,8) END NRINSC,   
       --infoExclusao
       EC.NMEVENTO tpEvento,
       EC.NRRECIBO nrRecEvt,
       --ideTrabalhador
       REPLACE(REPLACE(PH.NRCPFPESSOA,'.'),'-') cpfTrab,
       --ideFolhaPagto
       DECODE(EC.NMEVENTO, 'S-1250', EC.NRTABELA, 'S-1210', '', DECODE(CF.NRTIPOMOVIMENT,1,'1',2,'1',4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','2','1'),10,'1',19,'1','')) indApuracao,
       DECODE(EC.NMEVENTO, 'S-1250', TO_CHAR(EC.DTMESCOMPETENC,'YYYY-MM'), 'S-1210', TO_CHAR(EC.DTMESCOMPETENC,'YYYY-MM'), TO_CHAR(DECODE(EC.NMEVENTO,'S-1210',IC.DTOCORRENCIA,CF.DTOCORRENCIA), DECODE(CF.NRTIPOMOVIMENT,4,DECODE(TO_CHAR(CF.DTOCORRENCIA,'MM'),'12','YYYY','YYYY-MM'),'YYYY-MM'))) perApur
  FROM ESO_PERIODICO EC
  /*Empregador*/
  JOIN ESTRUTURAH EMH ON EMH.NRORG = :P_NRORG
                     AND EMH.NRESTRUTURAM = :P_NRESTRUTURAM
                     AND EMH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                               WHERE ESTRUTURAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC
                                                 AND ESTRUTURAH.NRESTRUTURAM = EMH.NRESTRUTURAM
                                                 AND ESTRUTURAH.NRORG = EMH.NRORG)
  JOIN PARCNEGOCIO PAR ON PAR.NRPARCNEGOCIO = EMH.NRPARCNEGOCIO
                      AND PAR.NRORG = EMH.NRORG
  /*ideTrabalhador*/
  LEFT JOIN GPE_PESSOAH PH ON PH.NRORG = EC.NRORG
                          AND PH.NRPESSOA = :P_NRIDETRABALHADOR
                          AND PH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_PESSOAH
                                                    WHERE GPE_PESSOAH.NRORG = PH.NRORG
                                                      AND GPE_PESSOAH.NRPESSOA = PH.NRPESSOA
                                                      AND GPE_PESSOAH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN GPE_VINCULOM VM ON VM.NRORG = PH.NRORG
                           AND VM.NRPESSOA = PH.NRPESSOA
  LEFT JOIN GPE_VINCULOH VH ON VH.NRORG = VM.NRORG
                           AND VH.NRVINCULOM = VM.NRVINCULOM
                           AND VH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                    WHERE GPE_VINCULOH.NRORG = VH.NRORG
                                                      AND GPE_VINCULOH.NRVINCULOM = VH.NRVINCULOM
                                                      AND GPE_VINCULOH.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  LEFT JOIN ESTRUTURAH EH ON EH.NRORG = VH.NRORG
                    AND EH.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    AND EH.DTMESCOMPETENC = (SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH H1
                                              WHERE H1.NRESTRUTURAM = EH.NRESTRUTURAM
                                                AND H1.NRORG = EH.NRORG
                                                AND H1.DTMESCOMPETENC <= :P_DTMESCOMPETENC)
  /*ideFolhaPagto*/
  LEFT JOIN FPA_CALCULOFOLHA CF ON CF.NRORG = EC.NRORG
                               AND CF.NRCALCULOFOLHA = :P_NRIDEFOLHAPAGTO
  LEFT JOIN FPA_ITECALCFOLHA IC ON IC.NRORG = CF.NRORG
                               AND IC.NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                               AND IC.NRVINCULOM = VM.NRVINCULOM
                               AND IC.NREVENTOM IN (3030,3050)
 WHERE EC.NRORG = :P_NRORG
   AND EC.NRENVIO = :P_NRENVIOORIG
   AND (((SUBSTR(EH.CDCNPJESTRUT,1,8) = SUBSTR(PAR.NRINSCRICAOPARC,1,8) OR EC.NMEVENTO = 'S-2190') AND :P_NRIDETRABALHADOR IS NOT NULL) OR (:P_NRIDETRABALHADOR IS NULL))
SQL;
        $params = array(
            "P_NRORG" => $this->hcmParameters->getNrorgTrabalho(),
            "P_DTMESCOMPETENC" => $this->hcmParameters->getDtCompetencia(),
            "P_NRENVIO" => $nrenvio,
            "P_NRESTRUTURAM" => $nrestruturam,
            "P_NRENVIOORIG" => $nrenvioorig,
            "P_NRIDETRABALHADOR" => $nrIdeTrabalhador,
            "P_NRIDEFOLHAPAGTO" => $nrIdeFolhaPgto,
        );
        return $this->connection->fetchAssoc($sql, $params);
    }

}